package HTTP::Balancer::Command::List;
use Modern::Perl;
use Moose;
with qw( HTTP::Balancer::Role::Stem );

use Text::Table;

sub run {
    my ($self, ) = @_;
}

1;
